// -----------------------------------------------------------------------
// Copyright (C) 2019-2025, EyeLogic GmbH
//
// Permission is hereby granted, free of charge, to any person or
// organization obtaining a copy of the software and accompanying
// documentation covered by this license (the "Software") to use,
// reproduce, display, distribute, execute, and transmit the Software,
// and to prepare derivative works of the Software, and to permit
// third-parties to whom the Software is furnished to do so.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE, TITLE AND
// NON-INFRINGEMENT. IN NO EVENT SHALL THE COPYRIGHT HOLDERS OR ANYONE
// DISTRIBUTING THE SOFTWARE BE LIABLE FOR ANY DAMAGES OR OTHER
// LIABILITY, WHETHER IN CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT
// OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.
// -----------------------------------------------------------------------

/**
 * @file ELEyeImage.h
 *
 * @brief The file specifies the C++ container for an eye image.
 */

#pragma once

#include "ELExports.hpp"

#include <cinttypes>

/** @brief namespace for C++ API calls */
namespace elapi
{
/**
 * @brief contains an image of the eyes captured by the device
 */
struct ELEyeImage final {
    /** @brief width of the image in pixels */
    static const int32_t WIDTH = 300;
    /** @brief height of the image in pixels */
    static const int32_t HEIGHT = 90;
    /** @brief size of the image buffer @see data in byte */
    static const int32_t SIZE = WIDTH * HEIGHT * 3;

    /** @brief image buffer, stores all pixels as RGB value (3 bytes per pixel) */
    uint8_t data[ SIZE ];
};
}  // namespace elapi
