// -----------------------------------------------------------------------
// Copyright (C) 2019-2025, EyeLogic GmbH
//
// Permission is hereby granted, free of charge, to any person or
// organization obtaining a copy of the software and accompanying
// documentation covered by this license (the "Software") to use,
// reproduce, display, distribute, execute, and transmit the Software,
// and to prepare derivative works of the Software, and to permit
// third-parties to whom the Software is furnished to do so.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE, TITLE AND
// NON-INFRINGEMENT. IN NO EVENT SHALL THE COPYRIGHT HOLDERS OR ANYONE
// DISTRIBUTING THE SOFTWARE BE LIABLE FOR ANY DAMAGES OR OTHER
// LIABILITY, WHETHER IN CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT
// OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.
// -----------------------------------------------------------------------

/**
 * @file ELGazeEvent.h
 *
 * @brief The file specifies the C++ container for a gaze event.
 */

#pragma once

#include "ELExports.hpp"

#include <cinttypes>

/** @brief namespace for C++ API calls */
namespace elapi
{
/** @brief information about a fixation start */
struct ELFixationStart {
    /** @brief timepoint when the fixation started in microseconds after EPOCH */
    int64_t timestampMicroSec;

    /** @brief index of the corresponding GazeSample at which the fixation started */
    int32_t index;

    /**
     * @brief X coordinate of binocular point of regard on the stimulus plane at when the fixation
     * started
     */
    double porX;

    /**
     * @brief Y coordinate of binocular point of regard on the stimulus plane at when the fixation
     * started
     */
    double porY;
};

/** @brief information about a fixation end */
struct ELFixationStop {
    /** @brief timepoint when the fixation ended in microseconds after EPOCH */
    int64_t timestampMicroSec;
    /** @brief timepoint when the fixation started in microseconds after EPOCH */
    int64_t timestampStartMicroSec;

    /** @brief index of the corresponding GazeSample at which the fixation ended */
    int32_t index;
    /** @brief index of the corresponding GazeSample at which the fixation started */
    int32_t indexStart;

    /**
     * @brief X coordinate of binocular point of regard on the stimulus plane of the
     * overal fixation (average over the whole fixation period)
     */
    double porX;
    /**
     * @brief Y coordinate of binocular point of regard on the stimulus plane of the
     * overal fixation (average over the whole fixation period)
     */
    double porY;
};
}  // namespace elapi
