﻿// -----------------------------------------------------------------------
// Copyright (C) 2019-2025, EyeLogic GmbH
//
// Permission is hereby granted, free of charge, to any person or
// organization obtaining a copy of the software and accompanying
// documentation covered by this license (the "Software") to use,
// reproduce, display, distribute, execute, and transmit the Software,
// and to prepare derivative works of the Software, and to permit
// third-parties to whom the Software is furnished to do so.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE, TITLE AND
// NON-INFRINGEMENT. IN NO EVENT SHALL THE COPYRIGHT HOLDERS OR ANYONE
// DISTRIBUTING THE SOFTWARE BE LIABLE FOR ANY DAMAGES OR OTHER
// LIABILITY, WHETHER IN CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT
// OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.
// -----------------------------------------------------------------------

using eyelogic;

public class EyeImageDemoClient
{
    /** EyeLogic API object */
    private ELCsApi m_api;

    public bool
    start( MainWindow mainWindow )
    {
        try {
            // initialize API
            System.Console.WriteLine( "initialize EyeLogic API..." );
            m_api = new ELCsApi( "C# Client" );
            System.Console.WriteLine( "    ... done" );

            // register events
            m_api.OnEyeImage += mainWindow.onEyeImage;

            // connect to EyeLogic Server
            System.Console.WriteLine( "establish connection to server" );
            m_api.connect( );
            System.Console.WriteLine( "    ... done, connected" );

            // check if a device is connected
            ELCsApi.DeviceConfig deviceConfig = m_api.getDeviceConfig( );
            if ( deviceConfig == null ) {
                System.Console.WriteLine( "no device connected - exiting" );
                m_api.disconnect( );
                m_api.destroy( );
                System.Console.WriteLine( "press enter to quit" );
                System.Console.ReadLine( );
                return false;
            }
            System.Console.WriteLine( "device found, serial: {0}",
                                      deviceConfig.formatDeviceSerial( ) );

            // start tracking
            System.Console.WriteLine( "start tracking with default framerate" );
            m_api.requestTracking( 0 );
            System.Console.WriteLine( "    ... done" );

            // enable eye image stream
            System.Console.WriteLine( "enable the eye image stres" );
            m_api.streamEyeImages( true );
            System.Console.WriteLine( "    ... done" );

            return true;
        } catch ( ELException e ) {
            System.Console.WriteLine( e.ToString( ) + " (error ID: " + e.Error + ")" );
            if ( m_api != null ) {
                m_api.disconnect( );
                m_api.destroy( );
            }
            return false;
        }
    }

    public bool
    stop( )
    {
        try {
            // stop tracking
            System.Console.WriteLine( "stopping..." );
            m_api.unrequestTracking( );
            m_api.disconnect( );
            m_api.destroy( );
            System.Console.WriteLine( "    ... done" );
            return true;
        } catch ( ELException e ) {
            System.Console.WriteLine( e.ToString( ) + " (error ID: " + e.Error + ")" );
            if ( m_api != null ) {
                m_api.disconnect( );
                m_api.destroy( );
            }
            return false;
        }
    }
}
