# -----------------------------------------------------------------------
# Copyright (C) 2019-2023, EyeLogic GmbH
#
# Permission is hereby granted, free of charge, to any person or
# organization obtaining a copy of the software and accompanying
# documentation covered by this license (the "Software") to use,
# reproduce, display, distribute, execute, and transmit the Software,
# and to prepare derivative works of the Software, and to permit
# third-parties to whom the Software is furnished to do so.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
# MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE, TITLE AND
# NON-INFRINGEMENT. IN NO EVENT SHALL THE COPYRIGHT HOLDERS OR ANYONE
# DISTRIBUTING THE SOFTWARE BE LIABLE FOR ANY DAMAGES OR OTHER
# LIABILITY, WHETHER IN CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT
# OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
# -----------------------------------------------------------------------

from eyelogic.ELApi import *
import time
import cv2
import numpy as np

if __name__ == "__main__":

    #
    # This callback function is invoked when a new eye image is available.
    # The eyeImage parameter contains the image data as ctypes array of
    # bytes. The image data has a format of 300 px horizontal times 90 pixels
    # vertical, each pixel contains 3 bytes (red, green, blue value).
    # Note: Be sure to perform a deep copy of the eyeImage data when using
    # it outside the scope of this callback.
    #
    @EyeImageCallback
    def eyeImageCallback(eyeImage: POINTER(ELEyeImage)):
        im = np.ctypeslib.as_array(eyeImage.contents.data)
        image = im.reshape(90, 300, 3)
        cv2.namedWindow("Eye Image", cv2.WINDOW_NORMAL)
        cv2.resizeWindow("Eye Image", 600, 180)
        cv2.imshow("Eye Image", image)
        cv2.waitKey(1)

    api = ELApi("Demo Client")

    resultConnect = api.connect()
    if (resultConnect != ELApi.ReturnConnect.SUCCESS):
        print("Connection to server failed. Is the server up and running?",
              flush=True)
        input('Press Enter to exit')
        exit()
    print("Successfully connected to server", flush=True)

    deviceConfig = api.getDeviceConfig()
    if (deviceConfig.deviceSerial == 0):
        print("No device connected, will exit")
        input('Press Enter to exit')
        exit()
    else:
        print("Device found", flush=True)

    resultTracking = api.requestTracking(0)
    if (resultTracking != ELApi.ReturnStart.SUCCESS):
        print("Start tracking failed: {}".format(resultTracking), flush=True)
        input('Press Enter to exit')
        exit()

    api.registerEyeImageCallback(eyeImageCallback)
    api.streamEyeImages(True)

    # sleep some time and show eye images
    time.sleep(10)

    api.disconnect()
    api.registerEyeImageCallback(None)

    input('Press Enter to exit')
