# -----------------------------------------------------------------------
# Copyright (C) 2019-2025, EyeLogic GmbH
#
# Permission is hereby granted, free of charge, to any person or
# organization obtaining a copy of the software and accompanying
# documentation covered by this license (the "Software") to use,
# reproduce, display, distribute, execute, and transmit the Software,
# and to prepare derivative works of the Software, and to permit
# third-parties to whom the Software is furnished to do so.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
# MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE, TITLE AND
# NON-INFRINGEMENT. IN NO EVENT SHALL THE COPYRIGHT HOLDERS OR ANYONE
# DISTRIBUTING THE SOFTWARE BE LIABLE FOR ANY DAMAGES OR OTHER
# LIABILITY, WHETHER IN CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT
# OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
# -----------------------------------------------------------------------

from eyelogic.ELApi import *
import time

if __name__ == "__main__":

    api = ELApi("Demo Client")

    resultConnect = api.connect()
    if (resultConnect != ELApi.ReturnConnect.SUCCESS):
        print("Connection to server failed. Is the server up and running?",
              flush=True)
        input('Press Enter to exit')
        exit()
    print("Successfully connected to server: {}".format(api.isConnected()),
          flush=True)

    screenConfig = api.getActiveScreen()
    print("Screen resolution: {}x{}".format(screenConfig.resolutionX,
                                            screenConfig.resolutionY))

    deviceConfig = api.getDeviceConfig()
    if (deviceConfig.deviceSerial == 0):
        print("No device connected, will exit")
        input('Press Enter to exit')
        exit()
    else:
        print("Device found: framerates: {}".format(deviceConfig.frameRates), flush=True)

    resultTracking = api.requestTracking(0)
    if (resultTracking != ELApi.ReturnStart.SUCCESS):
        print("Start tracking failed: {}".format(resultTracking), flush=True)
        input('Press Enter to exit')
        exit()

    resultCalibrate = api.calibrate(0)
    if (resultCalibrate != ELApi.ReturnCalibrate.SUCCESS):
        print("Calibration failed: {}".format(resultCalibrate), flush=True)
        input('Press Enter to exit')
        exit()

    print("Calibrated successfully")

    resultValidate, validationData = api.validate()
    if (resultValidate != ELApi.ReturnValidate.SUCCESS):
        print("Validation failed: {}".format(resultValidate), flush=True)
        input('Press Enter to exit')
        exit()
    else:
        def printPoint(ptIdx, validationData):
            if (validationData.pointsData[ptIdx].meanDeviationLeftDeg == ELInvalidValue):
                strLeft = "left:       N/A,       N/A"
            else:
                strLeft = "left: {:5.1f} deg, {:6.1f} px".format(
                    validationData.pointsData[ptIdx].meanDeviationLeftDeg,
                    validationData.pointsData[ptIdx].meanDeviationLeftPx
                )
            if (validationData.pointsData[ptIdx].meanDeviationRightDeg == ELInvalidValue):
                strRight = "right:       N/A,       N/A"
            else:
                strRight = "right: {:5.1f} deg, {:6.1f} px".format(
                    validationData.pointsData[ptIdx].meanDeviationRightDeg,
                    validationData.pointsData[ptIdx].meanDeviationRightPx
                )
            print("{}. point. position [px]: {:4n}, {:4n} | {} | {}\n".format(ptIdx + 1,
                validationData.pointsData[ptIdx].validationPointPxY,
                validationData.pointsData[ptIdx].validationPointPxX,
                strLeft, strRight )
            )

        print("Validated successfully:\n", flush=True)
        printPoint(0, validationData)
        printPoint(1, validationData)
        printPoint(2, validationData)
        printPoint(3, validationData)

    api.disconnect()

    input('Press Enter to exit')